#
# spec file for package rubygem-asciidoctor
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
# This file was generated with a gem2rpm.yml and not just plain gem2rpm.
# All sections marked as MANUAL, license headers, summaries and descriptions
# can be maintained in that file. Please consult this file before editing any
# of those fields
#

Name:           rubygem-asciidoctor
Version:        2.0.20
Release:        1.1
%define mod_name asciidoctor
%define mod_full_name %{mod_name}-%{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  %{rubygem gem2rpm}
BuildRequires:  %{ruby}
BuildRequires:  ruby-macros >= 5
BuildRequires:  update-alternatives
URL:            https://asciidoctor.org
Source:         https://rubygems.org/gems/%{mod_full_name}.gem
Source1:        gem2rpm.yml
Summary:        An implementation of the AsciiDoc text processor and publishing
License:        MIT
Group:          Development/Languages/Ruby
PreReq:         update-alternatives

%description
A fast, open source text processor and publishing toolchain for converting
AsciiDoc content to HTML 5, DocBook 5, and other formats.

%prep

%build

%install
%gem_install \
  --symlink-binaries \
  --doc-files="LICENSE" \
  -f

%gem_packages

%changelog
* Wed Jun 21 2023 Osama Alrifai <osamaalrifai18@gmail.com>
- update to 2.0.20
  Bug Fixes::
  * Update `release-version` attribute in READMEs and man page during release
  * Rebuild man page during release
  === Details
  {url-repo}/releases/tag/v2.0.20[git tag] | {url-repo}/compare/v2.0.19\...v2.0.20[full diff]
  // end::compact[]
  == 2.0.19 (2023-05-17) - @mojavelinux
  Improvements::
  * Return empty string instead of nil if raw or verbatim block has no lines
  * Don't uppercase monospace span in section title in manpage output (#4402)
  * Simplify processing of implicit link (i.e., autolink) by separating implicit and explicit match
  * Generate partintro block consistently (#4450)
  * Add Kiswahili translation for built-in labels (PR #4454) (*@bkmgit*)
  Compliance::
  * Fix call order so use of an include file with invalid encoding continues to raise error when using Ruby >= 3.2.0
  * Fix test assertion for fallback Rouge stylesheet to be compatible with Rouge 4.1 (#4406) (*@tmzullinger*)
  * Support `notitle` option on section as alternative to `untitled` to hide title (#4437)
  * Add support for Haml 6 to template converter (#4429)
  Bug Fixes::
  * Process constrained inline passthrough inside monospace span (#4458)
  * Catalog inline ref defined using anchor macro even when resolved reftext is empty
  * Use while loop rather than recursion to locate next line to process; prevents stack limit error (#4368)
  * Avoid matching numeric character references when searching for # in xref target (#4393)
  * Use correct selector to collapse margin on first and last child of sidebar
  * Don't allow target of include directive to start with a space (to distinguish it from a dlist item) or to end with a space
  * Manify alt text of block image in manpage output (#4401)
  * Adjust font size of term in horizontal dlist to match font size of term in regular dlist
  * Implicitly attach nested list that starts with block attribute lines to dlist entry (#4268)
  * Don't swallow square brackets when processing escaped URL macro
  * Treat `uri:classloader:` as an absolute path prefix when running on JRuby (#3929)
  * Apply reftext substitutions to value of `mantitle` attribute in DocBook output (#4448)
  * Enclose `<reftext>` tag in `<article>` tag in DocBook output for man page (#4452)
  * Correctly handle compat role on monospace and constrained passthrough when box attrlist or formatted text is escaped
* Fri Oct 28 2022 Stephan Kulow <coolo@suse.com>
  updated to version 2.0.18
  see installed CHANGELOG.adoc
  == 2.0.18 (2022-10-15) - @mojavelinux
  Improvements::
  * Propagate `:to_dir` option to document of AsciiDoc table cell (#4297)
  * Force encoding of attribute data passed via CLI to UTF-8 if transcoding fails (#4351) (*@zkaip*)
  * Add include role to link macro that replaces include directive when include is not enabled
  Bug Fixes::
  * Change internal `uriish?` helper to only detect a URI pattern at start of a string; avoids misleading messages (#4357)
  * Prevent highlight.js warning when no language is set on source block; don't call `highlightBlock` if `data-lang` attribute is absent (#4263)
  * Don't raise error if `Asciidoctor::Extensions.unregister` is called before groups are initialized (#4270)
  * If path is included both partially and fully, store it with true value (included fully) in includes table of document catalog
  * Reset registry if activate is called on it again (#4256)
  * Format source location in exception message when extension code is malformed
  * Fix lineno on reader when `skip-front-matter` attribute is set but end of front matter is not found
  * Fix `Asciidoctor::Cli::Invoker` constructor when first argument is a hash
  * Update default stylesheet to honor marker on unordered list when marker is defined on ancestor unordered list (#4361)
  === Details
  {url-repo}/releases/tag/v2.0.18[git tag] | {url-repo}/compare/v2.0.17\...v2.0.18[source diff]
  // end::compact[]
* Tue Jan 25 2022 Stephan Kulow <coolo@suse.com>
  updated to version 2.0.17
  see installed CHANGELOG.adoc
* Thu Jun 24 2021 Stephan Kulow <coolo@suse.com>
  updated to version 2.0.15
  see installed CHANGELOG.adoc
* Wed Jan 20 2021 Stephan Kulow <coolo@suse.com>
  updated to version 2.0.12
  see installed CHANGELOG.adoc
* Fri Jul 19 2019 Stephan Kulow <coolo@suse.com>
- updated to version 2.0.10
  see installed CHANGELOG.adoc
  == 2.0.10 (2019-05-31) - @mojavelinux
  Bug Fixes::
  * fix Asciidoctor.convert_file to honor `header_footer: false` option when writing to file (#3316)
  * fix placement of title on excerpt block (#3289)
  * always pass same options to SyntaxHighlighter#docinfo, regardless of value of location argument
  * fix signature of SyntaxHighlighter#docinfo method (#3300)
  * when `icons` is set to `image`, enable image icons, but don't use it as the value of the `icontype` attribute (#3308)
  // end::compact[]
* Sun May  5 2019 Stephan Kulow <coolo@suse.com>
- updated to version 2.0.9
  see installed CHANGELOG.adoc
  // tag::compact[]
  == 2.0.9 (2019-04-30) - @mojavelinux
  Bug Fixes::
  * process multiple single-item menu macros in same line (#3279)
  * register images in catalog correctly (#3283)
  * rename AbstractNode#options method to AbstractNode#enabled_options so it doesn't get shadowed by Document#options (#3282)
  * don't fail to convert document if alt attribute is not set on block or inline image (typically by an extension)
  * fix lineno of source location on blocks that follow a detached list continuation (#3281)
  * assume inline image type is "image" if not set (typically by an extension)
  // end::compact[]
  == 2.0.8 (2019-04-22) - @mojavelinux
  Bug Fixes::
  * restore background color applied to literal blocks by default stylesheet (#3258)
  * use portability constants (CC_ALL, CC_ANY) in regular expressions defined in built-in converters (DocBook5 and ManPage)
  * use portability constant (CC_ANY) in regular expression for custom inline macros
  * use smarter margin collapsing for AsciiDoc table cell content; prevent passthrough content from being cut off (#3256)
  * don't limit footnote ref to ASCII charset; allow any word character in Unicode to be used (#3269)
  Improvements::
  * register_for methods accept arguments as symbols (#3274)
  * use Concurrent::Map instead of Concurrent::Hash in template converter
  * use module_function keyword to define methods in Helpers
  * move regular expression definitions to separate source file (internal change)
  == 2.0.7 (2019-04-13) - @mojavelinux
  Bug Fixes::
  * fix crash when resolving ID from text and at least one candidate contains an unresolved xref (#3254)
  * fix compatibility with Rouge 2.0
  Improvements::
  * improve documentation for the `-a` CLI option; explain that `@` modifier can be placed at end of name as alternative to end of value
  * move source for main API entry points (load, load_file, convert, convert_file) to separate files (internal change)
  * define main API entry points (load, load_file, convert, convert_file) as module functions
  Also see https://github.com/asciidoctor/asciidoctor/milestone/33?closed=1[issues resolved in 2.0.x] (cumulative).
  == 2.0.6 (2019-04-04) - @mojavelinux
  Bug Fixes::
  * assume implicit AsciiDoc extension on interdoc xref macro target with no extension (e.g., `document#`); restores 1.5.x behavior (#3231)
  * don't fail to load application if call to Dir.home fails; use a rescue with fallback values (#3238)
  * Helpers.rootname should only consider final path segment when dropping file extension
  Improvements::
  * implement Helpers.extname as a more efficient and flexible File.extname method
  * check for AsciiDoc file extension using end_with? instead of resolving the extname and using a lookup
  Also see https://github.com/asciidoctor/asciidoctor/milestone/33?closed=1[issues resolved in 2.0.x] (cumulative).
  == 2.0.5 (2019-04-01) - @mojavelinux
  Bug Fixes::
  * fix crash when source highlighter is Rouge and source language is not set on block (#3223)
  * update CLI and SyntaxHighlighter to allow Asciidoctor to load cleanly on Ruby 2.0 - 2.2
  * CLI should use $stdin instead of STDIN to be consistent with the use of $stdout
  * mark encoding of stdio objects used in CLI as UTF-8 (#3225)
  * make Asciidoctor::SyntaxHighlighter::Config.register_for method public as documented
  Also see https://github.com/asciidoctor/asciidoctor/milestone/33?closed=1[issues resolved in 2.0.x] (cumulative).
  == 2.0.4 (2019-03-31) - @mojavelinux
  Bug Fixes::
  * allow Asciidoctor to load cleanly on Ruby 2.0 - 2.2 for distributions that provide support for these older Ruby versions
  * make Asciidoctor::Converter::Config.register_for method public as documented
  * remove unused Asciidoctor::Converter::BackendTraits#derive_backend_traits private method
  * move Asciidoctor::Converter::BackendTraits.derive_backend_traits method to Asciidoctor::Converter
  * mark render and render_file methods as deprecated in API docs
  Also see https://github.com/asciidoctor/asciidoctor/milestone/33?closed=1[issues resolved in 2.0.x] (cumulative).
* Fri Mar 29 2019 Stephan Kulow <coolo@suse.com>
- updated to version 2.0.3
  see installed CHANGELOG.adoc
* Mon Nov 12 2018 Stephan Kulow <coolo@suse.com>
- updated to version 1.5.8
  see installed CHANGELOG.adoc
  == 1.5.8 (2018-10-28) - @mojavelinux
  Enhancements::
  * if set, add value of part-signifier and chapter-signifier attributes to part and chapter titles (#2738)
  * allow position (float) and alignment (align) to be set on video block (#2425)
  * substitute attribute references in attrlist of include directive (#2761)
  * add Document#set_header_attribute method for adding method directly to document header during parsing (#2820)
  * add helper method to extension processor classes to create lists and list items
  * allow ordered and unordered lists to be nested to an arbitrary / unlimited depth (#2854)
  * add `prefer` DSL method to extension registry and document processor to flag extension as preferred (#2848)
  * allow manname and manpurpose to be set using document attributes; don't look for NAME section in this case (#2810)
  * substitute attribute references in target of custom block macro (honoring attribute-missing setting) (#2839)
  * interpret `<.>` as an auto-numbered callout in verbatim blocks and callout lists (#2871)
  * require marker for items in callout list to have circumfix brackets (e.g., `<1>` instead of `1>`) (#2871)
  * preserve comment guard in front of callout number in verbatim block if icons is not enabled (#1360)
  * add more conventional styles to quote block when it has the excerpt role (#2092)
  * colspecs can be separated by semi-colon instead of comma (#2798)
  * change AbstractBlock#find_by to respond to StopIteration exception; stop traversal after matching ID (#2900)
  * change AbstractBlock#find_by to honor return values :skip and :skip_children from filter block to skip node and its descendants or just its descendants, respectively (#2067)
  * add API to retrieve authors as array; use API in converters (#1042) (*@mogztter*)
  * add support for start attribute on source block to set starting line number when converting to DocBook (#2915)
  * track imagesdir for image on node and in catalog (#2779)
  * allow starting line number to be set using start attribute when highighting source block with Pygments or CodeRay (#1742)
  * upgrade highlight.js to 9.13.1
  Fixes::
  * don't hang on description list item that begins with /// (#2888)
  * don't crash when using AsciiDoc table cell style on column in CSV table (#2817)
  * show friendly error if CSV data for table contains unclosed quote (#2878) (*@zelivans*)
  * don't crash when attribute entry continuation is used on last line of file (#2880) (*@zelivans*)
  * treat empty/missing value of named block attribute followed by other attributes (e.g., caption=,cols=2*) as empty string
  * AbstractNode#set_option does nothing if option is already set (PR #2778)
  * allow revnumber to be an attribute reference in revision info line (#2785)
  * use ::File.open instead of ::IO.binread in Reader for Asciidoctor.js compatibility
  * add fallback for timezone when setting doctime
  * preserve UNC path that begins with a double backslash (Windows) (#2869)
  * fix formatting of quote block (indentation) in manpage output (#2792)
  * catalog inline anchors in ordered list items (#2812)
  * detect closing tag on last line with no trailing newline (#2830)
  * process `!name@` attribute syntax property; follow-up to #642
  * change document extension processor DSL methods to return registered extension instance instead of array of instances
  * use fallback value for manname-title to prevent crash in manpage converter
  * consolidate inner whitespace in prose in manpage output (#2890)
  * only apply subs to node attribute value if enclosed in single quotes (#2905)
  * don't hide URI scheme if target of link macro is a bare URI scheme
  * fix crash when child section of part is out of sequence and section numbering is enabled (#2931)
  * fix crash when restoring passthroughs if passthrough role is enclosed in single quotes (#2882, #2883)
  * don't eagerly apply subs to inline attributes in general
  * make sure encoding of output file is UTF-8
  * prevent warning about invalid `:asciidoc` option when using custom templates with Slim 4 (#2928)
  * use Pathname#relative_path_from to compute relative path to file outside of base directory (#2108)
  Improvements::
  * change trailing delimiter on part number to colon (:) (#2738)
  * interpret open line range as infinite (#2914)
  * rename number property on AbstractBlock to numeral, but keep number as deprecated alias
  * use CSS class instead of hard-coded inline float style on tables and images (#2753)
  * use CSS class instead of hard-coded inline text-align style on block images (#2753)
  * allow hyphen to be used custom block macro name as long as it's not the first character (#2620)
  * use shorthands %%F and %%T instead of %%Y-%%m-%%d and %%H:%%M:%%S to format time
  * read file in binary mode whenever contents are being normalized
  * use .drop(0) to duplicate arrays (roughly 1.5x as fast as .dup)
  * only recognize a bullet glyph which is non-repeating as an unordered list marker
  * rename SyntaxDsl module to SyntaxProcessorDsl (internal)
  * fail if name given to block macro contains illegal characters
  * normalize all whitespace in value of manpurpose attribute
  * make space before callout number after custom line comment character optional
  * parse attrlist on inline passthrough as a shorthand attribute syntax or literal role (#2910)
  * add support for range syntax (.. delimiter) to highlight attribute on source block (#2918)
  * add support for unbounded range to highlight attribute on source block (#2918)
  * automatically assign title and caption on image block if title is set on custom block source (#2926)
  * use OS independent timezone (UTC or time offset) in doctime and localtime attributes (#2770)
  * report correct line number for inline anchor with id already in use (#2769)
  * generate manpage even if input is non-conforming or malformed (#1639)
  * allow authorinitials for single author to be overridden (#669)
  Documentation::
  * translate README into German (#2829) (*@jwehmschulte*)
  * sync French translation of README (*@mogztter*)
  * add Swedish translation of built-in attributes (PR #2930) (*@jonasbjork*)
  Build / Infrastructure::
  * replace thread_safe with concurrent-ruby (PR #2822) (*@junaruga*)
  // tag::compact[]
* Wed May 16 2018 factory-auto@kulow.org
- updated to version 1.5.7.1
  see installed CHANGELOG.adoc
  == 1.5.7.1 (2018-05-10) - @mojavelinux
  Fixes::
  * fix regression where block attributes where being inherited by sibling blocks in a complex list item (#2771)
  * don't apply lead styling to first paragraph in nested document (AsciiDoc table cell) if role is present (#2624)
  Build / Infrastructure::
  * drop obsolete logic in rake build
  * allow lib dir to be overridden for tests using an environment variable (PR #2758)
  * load asciidoctor/version from LOAD_PATH in gemspec if not found locally (PR #2760)
* Thu May  3 2018 factory-auto@kulow.org
- updated to version 1.5.7
  see installed CHANGELOG.adoc
  == 1.5.7 (2018-05-02) - @mojavelinux
  Enhancements::
  * BREAKING: drop XML tags, character refs, and non-word characters (except hyphen, dot, and space) when auto-generating section IDs (#794)
  * * hyphen, dot, and space are replaced with value of idseparator, if set; otherwise, spaces are dropped
  * allow attribute names to contain any word character defined by Unicode (#2376, PR #2393)
  * route all processor messages through a logger instead of using Kernel#warn (#44, PR #2660)
  * add MemoryLogger for capturing messages sent to logger into memory (#44, PR #2660)
  * add NullLogger to prevent messages from being logged (#44, PR #2660)
  * log message containing source location / cursor as an object; provides more context (#44, PR #2660)
  * pass cursor for include file to `:include_location` key in message context (PR #2729)
  * add `:logger` option to API to set logger instance (#44, PR #2660)
  * add `--failure-level=LEVEL` option to CLI to force non-zero exit code if specified logging level is reached (#2003, PR #2674)
  * parse text of xref macro as attributes if attribute signature found (equal sign) (#2381)
  * allow xrefstyle to be specified per xref by assigning the xrefstyle attribute on the xref macro (#2365)
  * recognize target with .adoc extension in xref macro as an interdocument xref
  * resolve nested includes in remote documents relative to URI (#2506, PR #2511)
  * allow `relfilesuffix` attribute to control file extension used for interdoc xrefs (#1273)
  * support `!name@` (preferred), `!name=@`, `name!@`, and `name!=@` syntax to soft unset attribute from API or CLI (#642, PR #2649)
  * allow modifier to be placed at end of name to soft set an attribute (e.g., `icons@=font`) (#642, PR #2649)
  * interpret `false` attribute value defined using API as a soft unset (#642, PR #2649)
  * number parts if `partnums` attribute is set (#2298)
  * allow footnote macro to define or reference footnote reference (footnoteref macro now deprecated) (#2347, PR #2362)
  * allow custom converter to be used with custom templates; converter must declare that it supports templates (#2619)
  * allow manpage path for manpage help topic to be specified using ASCIIDOCTOR_MANPAGE_PATH environment variable (PR #2653) (*@aerostitch*)
  * if manpage cannot be found in default path inside gem, use `man -w asciidoctor` to resolve installed path (PR #2653)
  * uncompress contents of manpage for manpage help topic if path ends with .gz (PR #2653) (*@aerostitch*)
  * define source and manual refmiscinfo entries in manpage output if manual and source attributes are defined (PR #2636) (*@tiwai*)
  * add syntax for adding hard line breaks in block AsciiMath equations (#2497, PR #2579) (*@dimztimz*)
  * add positioning option to sectanchors attribute (sectanchors=before or sectanchors=after) (#2485, PR #2486)
  * allow table striping to be configured using stripes attribute (even, odd, all, or none) or stripes roles on table (#1365, PR #2588)
  * recognize `ends` as an alias to `topbot` for configuring the table frame
  * add rel=nofollow property to links (text or image) when nofollow option is set (#2605, PR #2692)
  * populate Document#source_location when sourcemap option is enabled (#2478, PR #2488)
  * populate source_location property on list items when sourcemap option is set on document (PR #2069) (*@mogztter*)
  * populate Table::Cell#source_location when sourcemap option is enabled (#2705)
  * allow local include to be flagged as optional by setting optional option (#2389, PR #2413)
  * allow block title to begin with a period (#2358, PR #2359)
  * catalog inline anchor at start of list items in ordered and unordered lists, description list terms, and table cells (#2257)
  * register document in catalog if id is set; assign reftext to document attributes if specified in a block attribute line (#2301, PR #2428)
  * allow automatic width to be applied to individual columns in a table using the special value `~` (#1844)
  * use the quote element in DocBook converter to represent smart quotes (#2272, PR #2356) (@bk2204)
  * parse and pass all manpage names to output document master (i.e., shadow man pages) (#1811, #2543, PR #2414)
  * parse credit line of shorthand quote block as block attributes; apply normal subs to credit line in shorthand quote blocks (#1667, PR #2452)
  * populate copyright element in DocBook output from value of copyright attribute (#2728)
  * preserve directories if source dir and destination dir are set (#1394, PR #2421)
  * allow linkcss to be unset from API or CLI when safe mode is secure
  * convert quote to epigraph element in DocBook output if block has epigraph role (#1195, PR #2664) (*@bk2204*)
  * number special sections in addition to regular sections when sectnums=all (#661, PR #2463)
  * upgrade to Font Awesome 4.7.0 (#2569)
  * upgrade to MathJax 4.7.4
  Bug fixes::
  * set `:to_dir` option value correctly when output file is specified (#2382)
  * preserve leading indentation in contents of AsciiDoc table cell if contents starts with a newline (#2712)
  * the shorthand syntax on the style to set block attributes (id, roles, options) no longer resets block style (#2174)
  * match include tags anywhere on line as long as offset by word boundary on left and space or newline on right (#2369, PR #2683)
  * warn if an include tag specified in the include directive is unclosed in the included file (#2361, PR #2696)
  * use correct parse mode when parsing blocks attached to list item (#1926)
  * fix typo in gemspec that removed README and CONTRIBUTING files from the generated gem (PR #2650) (*@aerostitch*)
  * preserve id, role, title, and reftext on open block when converting to DocBook; wrap in `<para>` or `<formalpara>` (#2276)
  * don't turn bare URI scheme (no host) into a link (#2609, PR #2611)
  * don't convert inter-document xref to internal anchor unless entire target file is included into current file (#2200)
  * fix em dash replacement in manpage converter (#2604, PR #2607)
  * don't output e-mail address twice when replacing bare e-mail address in manpage output (#2654, PR #2665)
  * use alternate macro for monospaced text in manpage output to not conflict w/ AsciiDoc macros (#2751)
  * enforce that absolute start path passed to PathResolver#system_path is inside of jail path (#2642, PR #2644)
  * fix behavior of PathResolver#descends_from? when base path equals / (#2642, PR #2644)
  * automatically recover if start path passed to PathResolver#system_path is outside of jail path (#2642, PR #2644)
  * re-enable left justification after invoking tmac URL macro (#2400, PR #2409)
  * don't report warning about same level 0 section multiple times (#2572)
  * record timings when calling convert and write on Document (#2574, PR #2575)
  * duplicate header attributes when restoring; allows header attributes to be restored an arbitrary number of times (#2567, PR #2570)
  * propagate `:catalog_assets` option to nested document (#2564, PR #2565)
  * preserve newlines in quoted CSV data (#2041)
  * allow opening quote around quoted CSV field to be on a line by itself
  * output table footer after body rows (#2556, PR #2566) (*@PauloFrancaLacerda*)
  * move @page outside of @media print in default stylesheet (#2531, PR #2532)
  * don't throw exception if text of dd node is nil (#2529, PR #2530)
  * don't double escape ampersand in manpage output (#2525) (*@dimztimz*)
  * fix crash when author_1 attribute is assigned directly (#2481, PR #2487)
  * fix CSS for highlighted source block inside colist (#2474, PR #2490)
  * don't append file extension to data uri of admonition icon (#2465, PR #2466)
  * fix race condition in Helpers.mkdir_p (#2457, PR #2458)
  * correctly process nested passthrough inside unconstrained monospaced (#2442, PR #2443)
  * add test to ensure ampersand in author line is not double escaped (#2439, PR #2440)
  * prevent footnote ID from clashing with auto-generated footnote IDs (#2019)
  * fix alignment of icons in footnote (#2415, PR #2416)
  * add graceful fallback if pygments.rb fails to return a value (#2341, PR #2342)
  * escape specialchars in source if pygments fails to highlight (#2341)
  * do not recognize attribute entry line if name contains colon (PR #2377)
  * allow flow indexterm to be enclosed in round brackets (#2363, PR #2364)
  * set outfilesuffix to match file extension of output file (#2258, PR #2367)
  * add block title to dlist in manpage output (#1611, PR #2434)
  * scale text to 80%% in print styles (#1484, PR #2576)
  * fix alignment of abstract title when using default stylesheet (PR #2732)
  * only set nowrap style on table caption for auto-width table (#2392)
  * output non-breaking space for man manual if absent in DocBook output (PR #2636)
  * don't crash if stem type is not recognized (instead, fallback to asciimath)
  Improvements / Refactoring::
  * BREAKING: rename table spread role to stretch (#2589, PR #2591)
  * use cursor marks to track lines more accurately; record cursor at the start of each block, list item, or table cell (PR #2701, PR #2547) (*@seikichi*)
  * log a warning message if an unterminated delimited block is detected (#1133, PR #2612)
  * log a warning when nested section is found inside special section that doesn't support nested sections (#2433, PR #2672)
  * read files in binary mode to disable automatic endline coercion (then explicitly coerce to UTF-8) (PR #2583, PR #2694)
  * resolve / expand parent references in start path passed to PathResolver#system_path (#2642, PR #2644)
  * update PathResolver#expand_path to resolve parent references (#2642, PR #2644)
  * allow start path passed to PathResolver#system_path to be outside jail if target brings resolved path back inside jail (#2642, PR #2644)
  * don't run File.expand_path on Dir.pwd (assume Dir.pwd is absolute) (#2642, PR #2644)
  * posixify working_dir passed to PathResolver constructor if absolute (#2642, PR #2644)
  * optimize detection for footnote* and indexterm* macros (#2347, PR #2362)
  * log a warning if a footnote reference cannot be resolved (#2669)
  * set logger level to DEBUG when verbose is enabled
  * coerce value of `:template_dirs` option to an Array (PR #2621)
  * make block roles specified using shorthand syntax additive (#2174)
  * allow paragraph to masquerade as open block (PR #2412)
  * move callouts into document catalog (PR #2394)
  * document ID defined in block attribute line takes precedence over ID defined inside document title line
  * don't look for link and window attributes on document when resolving these attributes for an image
  * when linkattrs is set, only parse attributes in link macro if equals is present
  * skip line comments in name section of manpage (#2584, PR #2585)
  * always activate extension registry passed to processor (PR #2379)
  * skip extension registry activation if no groups are registered (PR #2373)
  * don't apply lead styling to first paragraph if role is present (#2624, PR #2625)
  * raise clearer exception when extension class cannot be resolved (#2622, PR #2623)
  * add methods to read results from timings (#2578, PR #2580)
  * collapse bottom margin of last block in AsciiDoc table cell (#2568, PR #2593)
  * set authorcount to 0 if there are no authors (#2519, PR #2520)
  * validate fragment of interdoc xref that resolves to current doc (#2448, PR #2449)
  * put id attribute on tag around phrase instead of preceding anchor (#2445, PR #2446)
  * add .plist extension to XML circumfix comment family (#2430, PR #2431) (*@akosma*)
  * alias Document#title method to no args Document#doctitle method (#2429, PR #2432)
  * upgrade missing or unreadable include file to an error (#2424, PR #2426)
  * add compliance setting to disable natural cross references (#2405, PR #2460)
  * make hash in inter-document xref target optional if target has extension (#2404, PR #2406)
  * add CSS class to part that matches role (#2401, PR #2402)
  * add fit-content class to auto-width table (#2392)
  * automatically assign parent reference when adding node to parent (#2398, PR #2403)
  * leave inline anchor in section title as is if section has ID (#2243, PR #2427)
  * align and improve error message about invalid use of partintro between HTML5 and DocBook converters
  * rephrase warning when level 0 sections are found and the doctype is not book
  * report correct line number when duplicate bibliography anchor is found
  * only warn if thread_safe gem is missing when using built-in template cache
  * rename enumerate_section to assign_numeral; update API docs
  * drop deprecated compact option from CLI; remove from manpage
  * use more robust mechanism for lazy loading the asciimath gem
  * use consistent phrase to indicate the processor is automatically recovering from a problem
  * change Reader#skip_comment_lines to not return skipped lines
  * add styles to default stylesheet for display on Kindle (kf8) devices (PR #2475)
  * purge render method from test suite (except to verify alias)
  Documentation::
  * translate 'section-refsig' for German language (PR #2633) (*@ahus1*)
  * synchronize French README with English version (PR #2637) (*@flashcode*)
  Build / Infrastructure::
  * create an official logo for the project (#48) (*@mmajko*)
  * update Ruby versions in appveyor build matrix (PR #2388) (*@miltador*)
  * add mailinglist, changelog, source, and issues URI to gem spec
  * allow blocks and substitutions tests to be run directly
  * asciidoctor formula now available for Homebrew (*@zmwangx*)
  Distribution Packages::
  * https://rubygems.org/gems/asciidoctor[RubyGem (asciidoctor)]
  * https://apps.fedoraproject.org/packages/rubygem-asciidoctor[Fedora (asciidoctor)]
  * https://packages.debian.org/sid/asciidoctor[Debian (asciidoctor)]
  * https://packages.ubuntu.com/search?keywords=asciidoctor[Ubuntu (asciidoctor)]
  * https://pkgs.alpinelinux.org/packages?name=asciidoctor[Alpine Linux (asciidoctor)]
  * https://software.opensuse.org/package/rubygem-asciidoctor[OpenSUSE (rubygem-asciidoctor)]
* Tue Mar 20 2018 factory-auto@kulow.org
- updated to version 1.5.6.2
  see installed CHANGELOG.adoc
  == 1.5.6.2 (2018-03-20) - @mojavelinux
  Bug fixes::
  * fix match for multiple xref macros w/ implicit text in same line (#2450)
  * PathResolver#root? returns true for absolute URL in browser env (#2595)
  Improvements / Refactoring::
  * resolve include target correctly in browser (xmlhttprequest IO module) (#2599, #2602)
  * extract method to resolve include path (allowing Asciidoctor.js to override) (#2610)
  * don't expand docdir value passed to API (#2518)
  * check mandatory attributes when creating an image block (#2349)
  * drop is_ prefix from boolean methods in PathResolver (PR #2587)
  * change Reader#replace_next_line to return true
  * organize methods in AbstractNode
  Build / Infrastructure::
  * clean up dependencies
  * add Ruby 2.5.0 to CI build matrix (PR #2528)
  * update nokogiri to 1.8.0 for ruby >= 2.1 (PR #2380)
  Distribution Packages::
  * http://rubygems.org/gems/asciidoctor[RubyGem (asciidoctor)]
  * https://apps.fedoraproject.org/packages/rubygem-asciidoctor[Fedora (rubygem-asciidoctor)]
  * http://packages.debian.org/sid/asciidoctor[Debian (asciidoctor)]
  * http://packages.ubuntu.com/saucy/asciidoctor[Ubuntu (asciidoctor)]
  https://github.com/asciidoctor/asciidoctor/issues?q=milestone%%3Av1.5.6.2[issues resolved] |
  https://github.com/asciidoctor/asciidoctor/releases/tag/v1.5.6.2[git tag] |
  https://github.com/asciidoctor/asciidoctor/compare/v1.5.6.1...v1.5.6.2[full diff]
  // end::compact[]
* Thu Aug  3 2017 coolo@suse.com
- updated to version 1.5.6.1
  see installed CHANGELOG.adoc
  == 1.5.6.1 (2017-07-23) - @mojavelinux
  Bug fixes::
  * continue to read blocks inside a delimited block after content is skipped (PR #2318)
  * don't create an empty paragraph for skipped content inside a delimited block (PR #2319)
  * allow the subs argument of Substitutors#apply_subs to be nil
  * coerce group name to symbol when registering extension (#2324)
  * eagerly substitute attributes in target of inline image macro (#2330)
  * don't warn if source stylesheet can't be read but destination already exists (#2323)
  * track include path correctly if path is absolute and outside of base directory (#2107)
  * preprocess second line of setext section title (PR #2321)
  * preprocess second line of setext discrete heading (PR #2332)
  * return filename as relative path if filename doesn't share common root with base directory (#2107)
  Improvements / Refactoring::
  * change default text for inter-document xref (PR #2316)
  * add additional tests to test behavior of Reader#peek_lines
  * parse revision info line correctly that only has version and remark; add missing test for scenario
  * rename AtxSectionRx constant to AtxSectionTitleRx for consistency with SetextSectionTitleRx constant
  * use terms "atx" and "setext" to refer to section title syntax (PR #2334)
  * rename HybridLayoutBreakRx constant to ExtLayoutBreakRx
  * change terminology from "floating title" to "discrete heading"
  * consolidate skip blank lines and check for end of reader (PR #2325)
  * have Reader#skip_blank_lines report end of file (PR #2325)
  * don't mix return type of Parser.build_block method (PR #2328)
  * don't track eof state in reader (PR #2320)
  * use shift instead of advance to consume line when return value isn't needed (PR #2322)
  * replace terminology "floating title" with "discrete heading"
  * remove unnecessary nil_or_empty? checks in substitutor
  * leverage built-in assert / refute methods in test suite
  Build / Infrastructure::
  * config Travis CI job to release gem (PR #2333)
  * add SHA1 hash to message used for triggered builds
  * trigger build of AsciidoctorJ on every change to core
  * trigger build of Asciidoctor Diagram on every change to core
  Distribution Packages::
  * http://rubygems.org/gems/asciidoctor[RubyGem (asciidoctor)]
  * https://apps.fedoraproject.org/packages/rubygem-asciidoctor[Fedora (rubygem-asciidoctor)]
  * http://packages.debian.org/sid/asciidoctor[Debian (asciidoctor)]
  * http://packages.ubuntu.com/saucy/asciidoctor[Ubuntu (asciidoctor)]
  https://github.com/asciidoctor/asciidoctor/issues?q=milestone%%3Av1.5.6.1[issues resolved] |
  https://github.com/asciidoctor/asciidoctor/releases/tag/v1.5.6.1[git tag] |
  https://github.com/asciidoctor/asciidoctor/compare/v1.5.6...v1.5.6.1[full diff]
  // end::compact[]
  == 1.5.6 (2017-07-12) - @mojavelinux
  Enhancements::
  * use custom cross reference text if xrefstyle attribute is set (full, short, basic) (#858, #1132)
  * store referenceable nodes under refs key in document catalog (PR #2220)
  * apply reftext substitutions (specialchars, quotes, replacements) to value returned by reftext method (PR #2220)
  * add xreftext method to AbstractBlock, Section, and Inline to produce formatted text for xref (PR #2220)
  * introduce attributes chapter-refsig, section-refsig, and appendix-refsig to set reference signifier for chapter, section, and appendix, respectively (PR #2220)
  * add rel="noopener" to links that target _blank or when noopener option is set (#2071)
  * add option to exclude tags when including a file (#1516)
  * add meta for shortcut icon if favicon attribute is set (#1574)
  * allow use of linenums option to enable line numbers on a source block (#1981)
  * allow extension groups to be unregistered individually (#1701)
  * catalog bibliography anchors and capture reftext (#560, #1562)
  * automatically add bibliography style to unordered list in bibliography section (#1924)
  * disable startinline option when highlighting PHP if mixed option is set on source block (PR #2015) (@ricpelo)
  * configure Slim to resolve includes in specified template dirs (#2214)
  * dump manpage when -h manpage flag is passed to CLI (#2302)
  * add resolves_attributes method to DSL for macros (#2122)
  * invoke convert on result of custom inline macro if value is an inline node (#2132)
  * resolve attributes for custom short inline macros if requested (#1797)
  * add convenience method to create section from extension; use same initialization logic as parser (#1957)
  * add handles? method to DSL for IncludeProcessor (#2119)
  * pass through preload attribute to video tag (#2046)
  * add start and end times for audio element (#1930)
  * set localyear and docyear attributes (#1372)
  * pass cloaked context to block extension via cloaked-context attribute (#1606)
  * add support for covers in DocBook 5 converter (#1939)
  * accept named pipe (fifo) as the input file (#1948)
  * add AbstractBlock#next_adjacent_block helper method
  * rename Document#references to catalog; alias references to catalog (PR #2237)
  * rename extensions_registry option to extension_registry
  * rename Extensions.build_registry method to create
  * autoload extensions source file when Asciidoctor::Extensions is referenced (PR #2114, PR #2312)
  * apply default_attrs to custom inline macro (PR #2127)
  * allow tab separator for table to be specified using 	 (#2073)
  * add Cell#text= method
  Improvements::
  * significant improvements to performance, especially in parser and substitutors
  * process include directive inside text of short form preprocessor conditional (#2146)
  * add support for include tags in languages that only support only circumfix comments (#1729)
  * allow spaces in target of block image; target must start and end with non-space (#1943)
  * add warning in verbose mode if xref is not found (@fap-) (#2268)
  * add warning if duplicate ID is detected (#2244)
  * validate that output file will not overwrite input file (#1956)
  * include docfile in warning when stylesheet cannot be read (#2089)
  * warn if doctype=inline is used and block has unexpected content model (#1890)
  * set built-in docfilesuffix attribute (#1673)
  * make sourcemap field on Document read/write (#1916)
  * allow target of xref to begin with attribute reference (#2007)
  * allow target of xref to be expressed with leading # (#1546)
  * allow kbd and btn macros to wrap across multiple lines (#2249)
  * allow menu macro to span multiple lines; unescape escaped closing bracket
  * make menu macro less greedy
  * allow ampersand to be used as the first character of the first segment of a menu (#2171)
  * enclose menu caret in HTML tag (#2165)
  * use black text for menu reference; tighten word spacing (#2148)
  * fix parsing of keys in kbd macro (PR #2222)
  * add support for the window option for the link on a block image (#2172)
  * set correct level for special sections in parser (#1261)
  * always set numbered property on appendix to true
  * store number for formal block on node (#2208)
  * set sectname of header section to header (#1996)
  * add the remove_attr method to AbstractNode (#2227)
  * use empty string as default value for set_attr method (#1967)
  * make start argument to system_path optional (#1965)
  * allow API to control subs applied to ListItem text (#2035)
  * allow text of ListItem to be assigned (in an extension) (#2033)
  * make generate_id method on section a static method (#1929)
  * validate name of custom inline macro; cache inline macro rx (#2136)
  * align number in conum list to top by default (#1999)
  * fix CSS positioning of interactive checkbox (#1840)
  * fix indentation of list items when markers are disabled (none, no-bullet, unnumbered, unstyled) (PR #2286)
  * instruct icon to inherit cursor if inside a link
  * close all files opened internally (#1897)
  * be more precise about splitting kbd characters (#1660)
  * rename limit method on String to limit_bytesize (#1889)
  * leverage Ruby's match? method to speed up non-capturing regexps (PR #1938)
  * preserve inline break in manpages (@letheed)
  * check for presence of SOURCE_DATE_EPOCH instead of value; fail if value is malformed
  * add Rows#by_section method to return table sections (#2219)
  * cache which template engines have been loaded to avoid unnecessary processing
  * rename assign_index method to enumerate_section (PR #2242)
  * don't process double quotes in xref macro (PR #2241)
  * optimize attr and attr? methods (PR #2232)
  * use IO.write instead of File.open w/ block; backport for Opal
  * backport IO.binread to Ruby 1.8.7 to avoid runtime check
  * cache backend and doctype values on document
  * allow normalize option to be set on PreprocessorReader; change default to false
  * move regular expression constants for Opal to Asciidoctor.js build (PR #2070)
  * add missing comma in warning message for callout list item out of sequence
  * combine start_with? / end_with? checks into a single method call
  * rename UriTerminator constant to UriTerminatorRx
  * promote subs to top-level constants; freeze arrays
  * rename PASS_SUBS constant to NONE_SUBS
  * rename EOL constant to LF (retain EOL as alias)
  * rename macro regexp constants so name follows type (e.g., InlineImageMacroRx)
  Compliance::
  * retain block content in items of callout list when converting to HTML and man page (#1478)
  * only substitute specialchars for content in literal table cells (#1912)
  * fix operator logic for ifndef directive with multiple attributes (#1983)
  * only recognize uniform underline for setext section title (#2083)
  * don't match headings with mixed leading characters (#2074)
  * fix layout break from matching lines it shouldn't
  * fix behavior of attribute substitution in docinfo content (PR #2296)
  * encode spaces in URI (PR #2274)
  * treat empty string as a valid block title
  * preprocess lines of a simple block (#1923)
  * don't drop trailing blank lines when splitting source into lines (PR #2045)
  * only drop known AsciiDoc extensions from the inter-document xref path (#2217)
  * don't number special sections or special subsections by default (#2234)
  * assign sectname based on name of manuscript element (#2206)
  * honor leveloffset when resolving implicit doctitle (#2140)
  * permit leading, trailing, and repeat operators in target of preprocessor conditional (PR #2279)
  * don't match link macro in block form (i.e., has two colons after prefix) (#2202)
  * do not match bibliography anchor that begins with digit (#2247)
  * use [ 	] (or \s) instead of \p{Blank} to match spaces (#2204)
  * allow named entity to have trailing digits (e.g., there4) (#2144)
  * only assign style to image alt text if alt text is not specified
  * substitute replacements in non-generated alt text of block image (PR #2285)
  * keep track of whether alt text is auto-generated by assigning default-alt attribute (PR #2287)
  * suppress info element in docbook output if noheader attribute is set (#2155)
  * preserve leading indentation in literal and verse table cells (#2037)
  * preserve whitespace in literal and verse table cells (#2029)
  * set doctype-related attributes in AsciiDoc table cell (#2159)
  * fix comparison logic when preprocessing first line of AsciiDoc table cell
  * set filetype to man when backend is manpage (#2055)
  * respect image scaling in DocBook converter (#1059)
  * share counters between AsciiDoc table cells and main document (#1942)
  * generate ID for floating title from converted title (#2016)
  * split "treeprocessor" into two words; add aliases for compatibility (PR #2179)
  * allow trailing hyphen in attribute name used in attribute reference
  * allow escaped closing bracket in text of xref macro
  * process pass inline macro with empty text; invert extract logic
  * drop support for reftext document attribute (must be specified on node)
  * fix compliance with Haml >= 5 (load Haml eagerly; remove ugly option)
  * don't match inline image macro if target contains endline or leading or trailing spaces
  * assign id instead of target on ref/bibref node (PR #2307)
  * remove regexp hacks for Opal (#2110)
  * drop outdated quoting exceptions for Opal (PR #2081)
  Bug fixes::
  * don't allow table borders to cascade to nested tables (#2151)
  * escape special characters in reftext of anchor (#1694)
  * sanitize content of authors meta tag in HTML output (#2112)
  * fix stray marks added when unescaping unconstrained passthroughs (PR #2079)
  * don't confuse escaped quotes in CSV data as enclosing quotes (#2008)
  * don't activate implicit header if cell in first line of table contains a blank line (#1284, #644)
  * allow compat-mode in AsciiDoc table cell to inherit from parent document (#2153)
  * manify all normal table cell content (head, body, foot) in manpage output
  * add missing newline after table caption in manpage output (#2253)
  * correctly format block title on video in manpage output
  * don't crash if substitution list resolves to nil (#2183)
  * fail with informative message if converter cannot be resolved (#2161)
  * fix regression of not matching short form of custom block macro
  * encode double quotes in image alt text when used in an attribute (#2061)
  * encode double quote and strip XML tags in value of xreflabel attribute in DocBook converter (PR #2220)
  * fix typo in base64 data (PR #2094) (@mogztter)
  * permit pass macro to surround a multi-line attribute value with hard line breaks (#2211)
  * fix sequential inline anchor macros with empty reftext (#1689)
  * don't mangle compound names when document has multiple authors (#663)
  * don't drop last line of verbatim block if it contains only a callout number (#2043)
  * prevent leading & trailing round brackets from getting caught in indexterm (#1581)
  * remove cached title when title is set on block (#2022)
  * remove max-width on the callout number icon (#1895)
  * eagerly add hljs class for highlight.js (#2221)
  * fix SOURCE_DATE_EPOCH lookup in Opal
  * fix paths with file URI scheme are inevitably absolute (PR #1925) (@mogztter)
  * only resolve file URLs when JavaScript IO module is xmlhttprequest (PR #1898) (@mogztter)
  * fix formatting of video title in manpage converter
  * don't increment line number if peek_lines overruns buffer (fixes some cases when line number is off)
  * freeze extension processor instance, not class
  * fix numbering bug in reindex_sections
  * handle cases when there are no lines for include directive to select
  Documentation::
  * enable admonition icons in README when displayed on GitHub
  * add German translation of chapter-label (PR #1920) (@fap-)
  * add Ukrainian translation of built-in attributes (PR #1955) (@hedrok)
  * add Norwegian Nynorsk translation; updated Norwegian Bokmål translation of built-in attributes (PR #2142) (@huftis)
  * add Polish translation of built-in attributes (PR #2131) (@ldziedziul)
  * add Romanian translation of built-in attributes (PR #2125) (@vitaliel)
  * fix Japanese translation of built-in attributes (PR #2116) (@haradats)
  * add Bahasa Indonesia translation of built-in labels (@triyanwn)
  Build / Infrastructure::
  * upgrade highlight.js to 9.12.0 (#1652)
  * include entire test suite in gem (PR #1952) (@voxik)
  * upgrade Slim development dependency to 3.0.x (PR #1953) (@voxik)
  * upgrade Haml development dependency to 5.0.x
  * upgrade Nokogiri to 1.6.x (except on Ruby 1.8) (PR #1213)
  * add Ruby 2.4 to CI test matrix (PR #1980)
  * upgrade cucumber and JRuby in CI build (PR #2005)
  * fix reference to documentation in attributes.adoc (PR #1901) (@stonio)
  * trap and verify all warnings when tests are run with warnings enabled
  * set default task in build to test:all
  * configure run-tests.sh script to run all tests
  * configure feature tests to only show progress
  * configure Slim in feature tests to use html as format instead of deprecated html5
  * lock version of yard to fix invalid byte sequence in Ruby 1.9.3
  * modify rake build to trigger dependent builds (specifically, Asciidoctor.js) (@mogztter) (PR #2305)
  Distribution Packages::
  * http://rubygems.org/gems/asciidoctor[RubyGem (asciidoctor)]
  * https://apps.fedoraproject.org/packages/rubygem-asciidoctor[Fedora (rubygem-asciidoctor)]
  * http://packages.debian.org/sid/asciidoctor[Debian (asciidoctor)]
  * http://packages.ubuntu.com/saucy/asciidoctor[Ubuntu (asciidoctor)]
  https://github.com/asciidoctor/asciidoctor/issues?q=milestone%%3Av1.5.6[issues resolved] |
  https://github.com/asciidoctor/asciidoctor/releases/tag/v1.5.6[git tag] |
  https://github.com/asciidoctor/asciidoctor/compare/v1.5.5...v1.5.6[full diff]
* Thu Oct  6 2016 coolo@suse.com
- updated to version 1.5.5
  see installed CHANGELOG.adoc
* Wed Jan  6 2016 coolo@suse.com
- updated to version 1.5.4
  see installed CHANGELOG.adoc
  // tag::compact[]
  == 1.5.4 (2016-01-03) - @mojavelinux
  Enhancements::
  * translate README into French (@anthonny, @mogztter, @gscheibel, @mgreau) (#1630)
  * allow linkstyle in manpage output to be configured (#1610)
  Improvements::
  * upgrade to MathJax 2.6.0 and disable loading messages
  * upgrade to Font Awesome 4.5.0
  * disable toc if document has no sections (#1633)
  * convert inline asciimath to MathML (using asciimath gem) in DocBook converter (#1622)
  * add attribute to control build reproducibility (@bk2204) (#1453)
  * recognize file:/// as a file root in Opal browser env (#1561)
  * honor icon attribute on admonition block when font-based icons are enabled (@robertpanzer) (#1593)
  * resolve custom icon relative to iconsdir; add file extension if absent (#1634)
  * allow asciidoctor cli to resolve library path when invoked without leading ./
  Compliance::
  * allow special section to be nested at any depth (#1591)
  * ensure colpcwidth values add up to 100%%; increase precision of values to 4 decimal places (#1647)
  * ignore blank cols attribute on table (#1647)
  * support shorthand syntax for block attributes on document title (#1650)
  Bug fixes::
  * don't include default toc in AsciiDoc table cell; don't pass toc location attributes to nested document (#1582)
  * guard against nil dlist list item in find_by (#1618)
  * don't swallow trailing line when include file is not readable (#1602)
  * change xlink namespace to xl in DocBook 5 output to prevent parse error (#1597)
  * make callouts globally unique within document, including AsciiDoc table cells (#1626)
  * initialize Slim-related attributes regardless of when Slim was loaded (@terceiro) (#1576)
  * differentiate literal backslash from escape sequence in manpage output (@ds26gte) (#1604)
  * don't mistake line beginning with \. for troff macro in manpage output (@ds26gte) (#1589)
  * escape leading dots so user content doesn't trigger troff macros in manpage output (@ds26gte) (#1631)
  * use
* Tue Nov 24 2015 coolo@suse.com
- updated to version 1.5.3
  see installed CHANGELOG.adoc
  == 1.5.3 (2015-10-31) - @mojavelinux
  Enhancements::
  * add support for interactive & inline SVGs (#1301, #1224)
  * add built-in manpage backend (@davidgamba) (#651)
  * create Mallard backend; asciidoctor/asciidoctor-mallard (@bk2204) (#425)
  * add AsciiMath to MathML converter to support AsciiMath in DocBook converter (@pepijnve) (#954)
  * allow text of selected lines to be highlighted in source block by Pygments or CodeRay (#1429)
  * use value of `docinfo` attribute to control docinfo behavior (#1510)
  * add `docinfosubs` attribute to control which substitutions are performed on docinfo files (@mogztter) (#405)
  * add title accessor as alias to main on Document::Title (@rmannibucau) (#1350)
  * make XrefInlineRx regexp more permissive (Mathieu Boespflug) (#844)
  Improvements::
  * load JavaScript and CSS at the end of HTML document (@mogztter) (#1238)
  * list available backends in help text (@plaindocs) (#1271)
  * properly expand tabs in literal text (#1170, #841)
  * add `source-indent` as document attribute (@mogztter) (#1169)
  * upgrade MathJax to 2.5.3 (#1329)
  * upgrade Font Awesome to 4.4.0 (@mogztter) (#1465)
  * upgrade highlight.js to 8.6 (now 8.9.1) (#1390)
  * don't abort if syntax highlighter isn't available (#1253)
  * insert docinfo footer below footer div (#1503)
  * insert toc at default location in embeddable HTML (#1443)
  * replace _ and - in generated alt text for inline images
  * restore attributes to header attributes after parse (#1255)
  * allow docdate and doctime to be overridden (#1495)
  * add CSS class `.center` for center block alignment (#1456)
  * recognize U+2022 as alternative marker for unordered lists (@mogztter) (#1177)
  * allow videos to work for local files by prepending asset-uri-scheme (Chris) (#1320)
  * always assign playlist param when loop option is enabled for YouTube video
  * parse isolated version in revision line (@bk2204) (#790)
  * autoload Tilt when template converter is instantiated (#1313)
  * don't overwrite existing id entry in references table (#1256)
  * use outfilesuffix attribute defined in header when resolving outfile (#1412)
  * make AsciiDoc safe mode option on Slim engine match document (#1347)
  * honor htmlsyntax attribute when backend is html/html5 (#1530)
  * tighten spacing of wrapped lines in TOC (#1542)
  * tune padding around table cells in horizontal dlist (#1418)
  * load Droid Sans Mono 700 in default stylesheet
  * set line height of table cells used for syntax highlighting
  * set font-family of kbd; refine styling (#1423)
  * extract condition into `quote_lines?` method (@mogztter)
  * extract inline code into `read_paragraph` method (@mogztter)
  * parent of block in ListItem should be ListItem (#1359)
  * add helper methods to List and ListItem (#1551)
  * add method `AbstractNode#add_role` and `AbstractNode#remove_role` (@robertpanzer) (#1366)
  * introduce helper methods for sniffing URIs (#1422)
  * add helper to calculate basename without file extension
  * document `-I` and `-r` options in the manual page (@bk2204)
  * fix `+--help+` output text for `-I` (@bk2204)
  * don't require open-uri-cached if already loaded
  * do not attempt to scan pattern of non-existent directory
  Compliance::
  * use `<sup>` for footnote reference in text instead of `<span>` (#1523)
  * fix alignment of wrapped text in footnote (#1524)
  * include full stop after footnote number in embeddable HTML
  * show manpage title & name section in embeddable HTML (#1179)
  * resolve missing attribute in ifeval to empty string (#1387)
  * support unbreakable & breakable options on table (rockyallen) (#1140)
  Bug fixes::
  * don't truncate exception stack in `Asciidoctor.load` (#1248)
  * don't fail to save cause of Java exception (@robertpanzer) (#1458)
  * fix precision error in timings report (#1342)
  * resolve regexp for inline macro lazily (#1336)
  * block argument to `find_by` should filter results (#1393)
  * strip comment lines in indented text of dlist item (#1537)
  * preserve escaped delimiter at end of line in a table (#1306)
  * correctly calculate colnames for implicit columns (#1556)
  * don't crash if colspan exceeds colspec (#1460)
  * account for empty records in colspec (#1375)
  * ignore empty cols attribute on table
  * use `.inspect` to print MathJax delimiters (again) (#1198)
  * use while loop instead of begin/while loop to address bug in Asciidoctor.js (#1408)
  * force encoding of attribute values passed from cli (#1191)
  * don't copy css if stylesheet or stylesdir is a URI (#1400)
  * fix invalid color value in default CodeRay theme
  * built-in writer no longer fails if output is nil (#1544)
  * custom template engine options should take precedence
  * fallback to require with a non-relative path to support Debian package (@mogztter)
  * pass opts to recursive invocations of `PathResolver#system_path`
  * fix and test external links in docbook backend
  * use format symbol `:html` instead of `:html5` for Slim to fix warnings
  * fix documentation for inline_macro and block_macro (Andrea Bedini)
  * fix grammar in warning messages regarding thread_safe gem
  Infrastructure::
  * migrate opal_ext from core to Asciidoctor.js (#1517)
  * add Ruby 2.2 to CI build; only specify minor Ruby versions
  * enable containerized builds on Travis CI
  * add config to run CI build on AppVeyor
  * exclude benchmark folder from gem (#1522)
  Distribution Packages::
  * http://rubygems.org/gems/asciidoctor[RubyGem (asciidoctor)]
  * https://apps.fedoraproject.org/packages/rubygem-asciidoctor[Fedora (rubygem-asciidoctor)]
  * http://packages.debian.org/sid/asciidoctor[Debian (asciidoctor)]
  * http://packages.ubuntu.com/saucy/asciidoctor[Ubuntu (asciidoctor)]
  https://github.com/asciidoctor/asciidoctor/issues?q=milestone%%3Av1.5.3[issues resolved] |
  https://github.com/asciidoctor/asciidoctor/releases/tag/v1.5.3[git tag] |
  https://github.com/asciidoctor/asciidoctor/compare/v1.5.2...v1.5.3[full diff]
* Tue May 19 2015 mrueckert@suse.de
- update to 1.5.2
* Wed Jul 23 2014 mrueckert@suse.de
- initial package
